summaryrefslogtreecommitdiffstats
path: root/src/gallium/drivers/svga/svga_screen.h
diff options
context:
space:
mode:
authorNeha Bhende <[email protected]>2015-10-09 16:10:16 -0600
committerBrian Paul <[email protected]>2015-10-16 11:43:28 -0600
commit9bc7e3105aeadbe360ca9f060c50a181d3fa7a3d (patch)
tree9ac8d65c5cb875f6daa9823c3b0d8181cd4b7979 /src/gallium/drivers/svga/svga_screen.h
parentf413f1a17c506d5d4474a1baa0556a9e9f554c63 (diff)
svga: add new GALLIUM_HUD queries
Add new GALLIUM_HUD queries for: num-shaders num-resources num-state-objects num-validations map-buffer-time num-surface-views num-resources-mapped num-flushes Most of this patch was originally written by Neha. Additional clean-ups and num-flushes counter added by Brian Paul. Reviewed-by: Brian Paul <[email protected]> Reviewed-by: Charmaine Lee <[email protected]>
Diffstat (limited to 'src/gallium/drivers/svga/svga_screen.h')
-rw-r--r--src/gallium/drivers/svga/svga_screen.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/gallium/drivers/svga/svga_screen.h b/src/gallium/drivers/svga/svga_screen.h
index 5581d2e1ffd..98b56b2a6d1 100644
--- a/src/gallium/drivers/svga/svga_screen.h
+++ b/src/gallium/drivers/svga/svga_screen.h
@@ -80,8 +80,12 @@ struct svga_screen
struct svga_host_surface_cache cache;
- /** Memory used by all resources (buffers and surfaces) */
- uint64_t total_resource_bytes;
+ /** HUD counters */
+ struct {
+ /** Memory used by all resources (buffers and surfaces) */
+ uint64_t total_resource_bytes;
+ uint64_t num_resources;
+ } hud;
};
#ifndef DEBUG